.. grampg documentation master file, created by
   sphinx-quickstart on Mon Sep 24 20:13:26 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

grampg's documentation
======================

Password generation with a fluent interface... a nice treat when you're under supervision of a grumpy sysadmin.

Contents:

.. toctree::
   :maxdepth: 2

   grampg



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
